[Bf-blender-cvs] [54a3c7525bb] sculpt-dev: Merge branch 'master' into sculpt-dev

Joseph Eagar noreply at git.blender.org
Sat Mar 12 09:15:44 CET 2022


Commit: 54a3c7525bb9909bb29499d85a45a5fe50d527c0
Author: Joseph Eagar
Date:   Sat Mar 12 00:15:29 2022 -0800
Branches: sculpt-dev
https://developer.blender.org/rB54a3c7525bb9909bb29499d85a45a5fe50d527c0

Merge branch 'master' into sculpt-dev

===================================================================



===================================================================

diff --cc release/scripts/addons
index bdfb44b4256,bb62f10715a..c34f0b90d49
--- a/release/scripts/addons
+++ b/release/scripts/addons
@@@ -1,1 -1,1 +1,1 @@@
- Subproject commit bdfb44b4256c683360f05f5bde7159660f82c7b5
 -Subproject commit bb62f10715a871d7069d2b2c74b2efc97c3c350c
++Subproject commit c34f0b90d49938eccf9c1a9ae59b055155e00f9b
diff --cc release/scripts/presets/keyconfig/keymap_data/blender_default.py
index 2b360375edf,5a12d5c79f9..290f276c7d4
--- a/release/scripts/presets/keyconfig/keymap_data/blender_default.py
+++ b/release/scripts/presets/keyconfig/keymap_data/blender_default.py
@@@ -71,25 -73,23 +72,24 @@@ class Params
          "use_fallback_tool_select_mouse",
          # Shorthand for: `('CLICK' if self.use_fallback_tool_rmb else self.select_mouse_value)`.
          "select_mouse_value_fallback",
          # Shorthand for: `{"type": params.select_tweak, "value": 'ANY'}`.
          "select_tweak_event",
 -        # Shorthand for: `('CLICK_DRAG' if params.use_pie_click_drag else 'PRESS')`
 +        # Shorthand for: `('CLICK_DRAG' if params.use_pie_click_drag else
 +        # 'PRESS')`
          "pie_value",
          # Shorthand for: `{"type": params.tool_tweak, "value": 'ANY'}`.
          "tool_tweak_event",
          # Shorthand for: `{"type": params.tool_maybe_tweak, "value":
          # params.tool_maybe_tweak_value}`.
          #
 -        # NOTE: This is typically used for active tool key-map items however it should never
 -        # be used for selection tools (the default box-select tool for example).
 +        # NOTE: This is typically used for active tool key-map items however it
 +        # should never
 +        # be used for selection tools (the default box-select tool for
 +        # example).
          # Since this means with RMB select enabled in edit-mode for e.g.
          # `Ctrl-LMB` would be caught by box-select instead of add/extrude.
 -        "tool_maybe_tweak_event",
 -    )
 +        "tool_maybe_tweak_event",)
  
 -    def __init__(
 -            self,
 +    def __init__(self,
              *,
              legacy=False,
              select_mouse='RIGHT',
@@@ -331,10 -343,12 +325,11 @@@ def _template_items_gizmo_tweak_value()
  
  
  def _template_items_gizmo_tweak_value_click_drag():
 -    return [
 -        ("gizmogroup.gizmo_tweak",
 +    return [("gizmogroup.gizmo_tweak",
           {"type": 'LEFTMOUSE', "value": 'CLICK', **any_except("alt")}, None),
          ("gizmogroup.gizmo_tweak",
-          {"type": 'EVT_TWEAK_L', "value": 'ANY', **any_except("alt")}, None),]
+          {"type": 'LEFTMOUSE', "value": 'CLICK_DRAG', **any_except("alt")}, None),
+     ]
  
  
  def _template_items_gizmo_tweak_value_drag():
@@@ -343,15 -359,19 +340,17 @@@
  
  def _template_items_editmode_mesh_select_mode(params):
      if params.legacy:
 -        return [
 -            op_menu("VIEW3D_MT_edit_mesh_select_mode", {"type": 'TAB', "value": 'PRESS', "ctrl": True}),
 -        ]
 +        return [op_menu("VIEW3D_MT_edit_mesh_select_mode", {"type": 'TAB', "value": 'PRESS', "ctrl": True}),]
      else:
          return [
-             ("mesh.select_mode",
-                 {"type": k, "value": 'PRESS', **key_expand, **key_extend},
-                 {"properties": [*prop_extend, *prop_expand, ("type", e)]})
+             (
+                 "mesh.select_mode",
+                 {"type": NUMBERS_1[i], "value": 'PRESS', **key_expand, **key_extend},
+                 {"properties": [*prop_extend, *prop_expand, ("type", e)]}
+             )
              for key_expand, prop_expand in (({}, ()), ({"ctrl": True}, (("use_expand", True),)))
              for key_extend, prop_extend in (({}, ()), ({"shift": True}, (("use_extend", True),)))
-             for k, e in (('ONE', 'VERT'), ('TWO', 'EDGE'), ('THREE', 'FACE'))
+             for i, e in enumerate(('VERT', 'EDGE', 'FACE'))
          ]
  
  
@@@ -994,10 -1095,9 +1004,10 @@@ def km_outliner(params)
           {"properties": [("all", False)]}),
          ("outliner.item_openclose", {"type": 'LEFTMOUSE', "value": 'CLICK', "shift": True},
           {"properties": [("all", True)]}),
-         ("outliner.item_openclose", {"type": 'EVT_TWEAK_L', "value": 'ANY'},
+         ("outliner.item_openclose", {"type": 'LEFTMOUSE', "value": 'CLICK_DRAG'},
           {"properties": [("all", False)]}),
 -        # Fall through to generic context menu if the item(s) selected have no type specific actions.
 +        # Fall through to generic context menu if the item(s) selected have no
 +        # type specific actions.
          ("outliner.operation", {"type": 'RIGHTMOUSE', "value": 'PRESS'}, None),
          op_menu("OUTLINER_MT_context_menu", {"type": 'RIGHTMOUSE', "value": 'PRESS'}),
          op_menu_pie("OUTLINER_MT_view_pie", {"type": 'ACCENT_GRAVE', "value": 'PRESS'}),
@@@ -1072,11 -1177,12 +1082,11 @@@ def km_uv_editor(params)
              (op_tool, "builtin.select_box"), params),
          ("uv.select_box", {"type": 'B', "value": 'PRESS', "ctrl": True},
           {"properties": [("pinned", True)]}),
 -        op_tool_optional(
 -            ("uv.select_circle", {"type": 'C', "value": 'PRESS'}, None),
 +        op_tool_optional(("uv.select_circle", {"type": 'C', "value": 'PRESS'}, None),
              (op_tool, "builtin.select_circle"), params),
-         ("uv.select_lasso", {"type": params.action_tweak, "value": 'ANY', "ctrl": True},
+         ("uv.select_lasso", {"type": params.action_mouse, "value": 'CLICK_DRAG', "ctrl": True},
           {"properties": [("mode", 'ADD')]}),
-         ("uv.select_lasso", {"type": params.action_tweak, "value": 'ANY', "shift": True, "ctrl": True},
+         ("uv.select_lasso", {"type": params.action_mouse, "value": 'CLICK_DRAG', "shift": True, "ctrl": True},
           {"properties": [("mode", 'SUB')]}),
          ("uv.select_linked", {"type": 'L', "value": 'PRESS', "ctrl": True}, None),
          ("uv.select_linked_pick", {"type": 'L', "value": 'PRESS'},
@@@ -1104,20 -1211,24 +1114,21 @@@
          ),
          *_template_items_proportional_editing(
              params, connected=False, toggle_data_path='tool_settings.use_proportional_edit'),
-         ("transform.translate", {"type": params.select_tweak, "value": 'ANY'}, None),
-         op_tool_optional(("transform.translate", {"type": 'G', "value": 'PRESS'}, None),
+         ("transform.translate", {"type": params.select_mouse, "value": 'CLICK_DRAG'}, None),
+         op_tool_optional(
+             ("transform.translate", {"type": 'G', "value": 'PRESS'}, None),
              (op_tool_cycle, "builtin.move"), params),
 -        op_tool_optional(
 -            ("transform.rotate", {"type": 'R', "value": 'PRESS'}, None),
 +        op_tool_optional(("transform.rotate", {"type": 'R', "value": 'PRESS'}, None),
              (op_tool_cycle, "builtin.rotate"), params),
 -        op_tool_optional(
 -            ("transform.resize", {"type": 'S', "value": 'PRESS'}, None),
 +        op_tool_optional(("transform.resize", {"type": 'S', "value": 'PRESS'}, None),
              (op_tool_cycle, "builtin.scale"), params),
          ("transform.shear", {"type": 'S', "value": 'PRESS', "shift": True, "ctrl": True, "alt": True}, None),
          ("transform.mirror", {"type": 'M', "value": 'PRESS', "ctrl": True}, None),
          ("wm.context_toggle", {"type": 'TAB', "value": 'PRESS', "shift": True},
-          {"properties": [("data_path", 'tool_settings.use_snap')]}),
+          {"properties": [("data_path", 'tool_settings.use_snap_uv')]}),
          ("wm.context_menu_enum", {"type": 'TAB', "value": 'PRESS', "shift": True, "ctrl": True},
           {"properties": [("data_path", 'tool_settings.snap_uv_element')]}),
 -        *_template_items_context_menu("IMAGE_MT_uvs_context_menu", params.context_menu_event),
 -    ])
 +        *_template_items_context_menu("IMAGE_MT_uvs_context_menu", params.context_menu_event),])
  
      # Fallback for MMB emulation
      if params.use_mouse_emulate_3_button and params.select_mouse == 'LEFTMOUSE':
@@@ -1332,16 -1476,20 +1347,16 @@@ def km_view3d(params)
          ("view3d.view_axis", {"type": 'NDOF_BUTTON_TOP', "value": 'PRESS', "shift": True},
           {"properties": [("type", 'TOP'), ("align_active", True)]}),
          # Selection.
 -        *_template_view3d_select(
 -            type=params.select_mouse,
 +        *_template_view3d_select(type=params.select_mouse,
              value=params.select_mouse_value_fallback,
 -            legacy=params.legacy,
 -        ),
 -        op_tool_optional(
 -            ("view3d.select_box", {"type": 'B', "value": 'PRESS'}, None),
 +            legacy=params.legacy,),
 +        op_tool_optional(("view3d.select_box", {"type": 'B', "value": 'PRESS'}, None),
              (op_tool, "builtin.select_box"), params),
-         ("view3d.select_lasso", {"type": params.action_tweak, "value": 'ANY', "ctrl": True},
+         ("view3d.select_lasso", {"type": params.action_mouse, "value": 'CLICK_DRAG', "ctrl": True},
           {"properties": [("mode", 'ADD')]}),
-         ("view3d.select_lasso", {"type": params.action_tweak, "value": 'ANY', "shift": True, "ctrl": True},
+         ("view3d.select_lasso", {"type": params.action_mouse, "value": 'CLICK_DRAG', "shift": True, "ctrl": True},
           {"properties": [("mode", 'SUB')]}),
 -        op_tool_optional(
 -            ("view3d.select_circle", {"type": 'C', "value": 'PRESS'}, None),
 +        op_tool_optional(("view3d.select_circle", {"type": 'C', "value": 'PRESS'}, None),
              (op_tool, "builtin.select_circle"), params),
          # Borders.
          ("view3d.clip_border", {"type": 'B', "value": 'PRESS', "alt": True}, None),
@@@ -1355,16 -1503,21 +1370,17 @@@
          ("view3d.copybuffer", {"type": 'C', "value": 'PRESS', "ctrl": True}, None),
          ("view3d.pastebuffer", {"type": 'V', "value": 'PRESS', "ctrl": True}, None),
          # Transform.
-         ("transform.translate", {"type": params.select_tweak, "value": 'AN

@@ Diff output truncated at 10240 characters. @@
@@@ -71,25 -73,23 +72,24 @@@ class Params
          # Shorthand for: `('CLICK' if self.use_fallback_tool_rmb else self.select_mouse_value)`.
          "select_mouse_value_fallback",
-         # Shorthand for: `{"type": params.select_tweak, "value": 'ANY'}`.
+         # Shorthand for: `{"type": params.select_mouse, "value": 'CLICK_DRAG'}`.
          "select_tweak_event",
 -        # Shorthand for: `('CLICK_DRAG' if params.use_pie_click_drag else 'PRESS')`
@@@ -71,25 -73,23 +72,24 @@@ class Params
 +        # 'PRESS')`
          "pie_value",
-         # Shorthand for: `{"type": params.tool_tweak, "value": 'ANY'}`.
+         # Shorthand for: `{"type": params.tool_mouse, "value": 'CLICK_DRAG'}`.
          "tool_tweak_event",
@@@ -71,25 -73,23 +72,24 @@@ class Params
          "tool_tweak_event",
-         # Shorthand for: `{"type": params.tool_maybe_tweak, "value":
-         # params.tool_maybe_tweak_value}`.
+         # Shorthand for: `{"type": params.tool_mouse, "value": params.tool_maybe_tweak_value}`.
          #
 -        # NOTE: This is typically used for active tool key-map items however it should never



More information about the Bf-blender-cvs mailing list